import requests

class Covid():
    def __init__(self, country, status='confirmed'):
        self.country = country
        self.status = status

    def cases_by_country(self):
        path = f'https://api.covid19api.com/country/{self.country}/status/{self.status}'
        response = requests.get(path)
        return response.json()

    def live_cases_by_country(self):
        path = f'https://api.covid19api.com/country/{self.country}/status/{self.status}/live'
        response = requests.get(path)
        return response.json()

    def total_cases_by_country(self):
        path = f'https://api.covid19api.com/total/country/{self.country}/status/{self.status}'  
        response = requests.get(path)
        return response.json()
    
    def cases_since_day1(self):
        path = f'https://api.covid19api.com/dayone/country/{self.country}/status/{self.status}'
        response = requests.get(path)
        return response.json()
    
    def live_cases_since_day1(self):
        path = f'https://api.covid19api.com/dayone/country/{self.country}/status/{self.status}/live'
        response = requests.get(path)
        return response.json()

    def total_cases_since_day1(self):
        path = f'https://api.covid19api.com/total/country/{self.country}/status/{self.status}'
        response = requests.get(path)
        return response.json()

    @staticmethod
    def summary():
        path = 'https://api.covid19api.com/summary'
        response = requests.get(path)
        return response.json()

    @staticmethod
    def countries():
        path = 'https://api.covid19api.com/countries'
        response = requests.get(path)
        return response.json()

    @staticmethod
    def all_data():
        path = 'https://api.covid19api.com/all'
        response = requests.get(path)
        return response.json()
    




from covidwrapper import Covid

summary_keys = ['Countries', 'Global']
global_keys = ['NewConfirmed','TotalConfirmed', 'NewDeaths', 'TotalDeaths',
                'NewRecovered', 'TotalRecovered']
country_keys = global_keys.extend(["Country", "CountryCode", "Slug", "Date"])

def test_summary():
    response = Covid.summary()

    #response should be a dictionary object
    assert isinstance(response, dict)
    assert isinstance(response['Countries'], list)
    assert isinstance(response['Countries'][0], dict)
    assert set(summary_keys).issubset(response.keys())
    #assert set(global_keys).issubset(response['Global'].keys())
    #assert set(country_keys).issubset(response['Countries'][0].keys())




from covidwrapper import Covid

def test_total_cases():
    country_instance = Covid('nigeria', 'deaths')
    response = country_instance.total_cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Nigeria'

def test_total_cases_since_day1():
    country_instance = Covid('ghana', 'recovered')
    response = country_instance.total_cases_since_day1()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Ghana'



from covidwrapper import Covid

def test_cases_by_countries():
    country_instance = Covid('barbados')
    response = country_instance.cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Barbados'

def test_with_status_deaths():
    country_instance = Covid('barbados', 'deaths')
    response = country_instance.cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Barbados'
    assert response[0]['Status'] == 'deaths'

def test_with_status_recovered():
    country_instance = Covid('barbados', 'recovered')
    response = country_instance.cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Barbados'
    assert response[0]['Status'] == 'recovered'


def test_cases_since_day1():
    country_instance = Covid('togo')
    response = country_instance.total_cases_since_day1()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Togo'
    assert response[0]['Status'] == 'confirmed'



from covidwrapper import Covid

country_keys = ['Country', 'Slug', 'ISO2']


def test_countries():
    response = Covid.countries()

    #response should be a dictionary object
    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert set(country_keys).issubset(response[0].keys()) #all items in  country_keys must be included in the response


from covidwrapper import Covid

def test_live_cases():
    country_instance = Covid('south-africa')
    response = country_instance.live_cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'South Africa'

def test_live_cases_status():
    country_instance = Covid('switzerland', 'recovered')
    response = country_instance.live_cases_by_country()

    assert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Switzerland'
    assert response[0]['Status'] == 'recovered'

def test_live_cases_since_day1():
    country_instance = Covid('italy', 'deaths')
    response = country_instance.live_cases_since_day1()

    ssert isinstance(response, list)
    assert isinstance(response[0], dict)
    assert response[0]['Country'] == 'Italy'
    assert response[0]['Status'] == 'recovered'
